CREATE TABLE IF NOT EXISTS cell_info (
    cell_info_id	INTEGER PRIMARY KEY AUTOINCREMENT,
    cell_id         INTEGER,
    lac             INTEGER,
    UNIQUE (cell_id,lac)
);

CREATE TABLE IF NOT EXISTS staticdata (
  _id INTEGER PRIMARY KEY AUTOINCREMENT,
  timestamp INTEGER,
  deviceExternalId TEXT,
  dialingNumber TEXT,
  imei TEXT,
  imsi TEXT,
  devicemake TEXT,
  devicemodel TEXT,
  wifimacaddress TEXT,
  devicebuild TEXT,
  screenheight TEXT,
  screenwidth TEXT,
  cdma_nid TEXT,
  cdma_sid TEXT,
  sim_mcc TEXT,
  sim_mnc TEXT,
  sim_carrier TEXT,
  osVersion TEXT,
  locale TEXT,
  timezone_offset INTEGER,
  client_version TEXT,
  android_id TEXT
);

CREATE TABLE IF NOT EXISTS DCEvent2 (
  _id INTEGER PRIMARY KEY AUTOINCREMENT,
  location_id INTEGER,
  cell_info_id INTEGER,
  mobile_networktype TEXT,
  isroaming INTEGER,
  rssi_voice INTEGER,
  battery_level INTEGER,
  battery_voltage INTEGER,
  app_at_top_id INTEGER,
  charge_status INTEGER,
  wifi_ssid_id INTEGER,
  trafficstatsall_tx INTEGER,
  trafficstatsall_rx INTEGER,
  trafficstatsmobile_tx INTEGER,
  trafficstatsmobile_rx INTEGER,
  wifi_status INTEGER,
  isbluetoothon INTEGER,
  gps_status INTEGER,
  battery_temperature INTEGER,
  app_name TEXT,
  wifi_avail_ssid TEXT,
  time INTEGER,
  event_id INTEGER
);

CREATE TABLE IF NOT EXISTS timeBasedPatternData (
  day_of_week INTEGER,
  hour INTEGER,
  charge_start_time INTEGER,
  charge_level_increase INTEGER,
  charge_duration INTEGER,
  day INTEGER,
  battery_changed_level INTEGER,
  is_charge INTEGER,
  wifi_ssid_id INTEGER
);

CREATE TABLE IF NOT EXISTS locationBasedPatternData (
  cell_info_id INTEGER,
  wifi_ssid_id INTEGER,
  location_mode INTEGER,
  confirmed  INTEGER,
  network_latitude DOUBLE,
  network_longitude DOUBLE,
  availbssids STRING,
  update_time INTEGER,
  location_id INTEGER,
  location_name TEXT
);

CREATE TABLE IF NOT EXISTS locationInfo (
  location_id INTEGER PRIMARY KEY,
  user_turn_off_wifi INTEGER default 0
);

CREATE TABLE IF NOT EXISTS app_crash (
  crash_id INTEGER PRIMARY KEY AUTOINCREMENT,
  app_id INTEGER,
  app_version TEXT,
  crash_time INTEGER,
  crash_msg TEXT,
  crash_type INTEGER
);


CREATE TABLE IF NOT EXISTS alertLog (
  _id INTEGER primary key autoincrement,
  category_name TEXT,
  title TEXT,
  priority INTEGER,
  archive_flag INTEGER,
  log_time INTEGER,
  expire_time INTEGER,
  sub_category_name TEXT,
  state TEXT,
  category_id INTEGER,
  sub_category_id INTEGER,
  trigger_event TEXT,
  additional_column1 TEXT,
  additional_column2 TEXT,
  additional_column3 TEXT
);

INSERT into alertLog (category_id, sub_category_id, priority, state, archive_flag, log_time, expire_time)
VALUES(58, 25, 2, "state=O|ic_onboard_android_whisperer||welcome_notification_title|welcome_notification_content|welcome||", 2, strftime('%s','now')*1000, strftime('%s','now')*1000 + 72 * 3600 * 1000);

CREATE TABLE IF NOT EXISTS batteryIdleDrainInfo (
  _id INTEGER PRIMARY KEY AUTOINCREMENT,
  start_time INTEGER,
  end_time INTEGER,
  start_drain_level INTEGER,
  drain_level INTEGER,
  drain_duration INTEGER,
  event_type TEXT
);

-- creation for a daily aggregation overall device data infor;
CREATE TABLE IF NOT EXISTS agg_daily_overall_info (
   day INTEGER,
   day_Of_week INTEGER,
   fore_drain_level INTEGER,
   fore_drain_dur INTEGER,
   fore_drain_rate DOUBLE,
   back_drain_level INTEGER,
   back_drain_dur INTEGER,
   back_drain_rate DOUBLE, 
   is_overnight_charge INTEGER,
   battery_health_index INTEGER,
   mobile_data_usage INTEGER,
   wifi_data_usage INTEGER,
   mobile_used_time INTEGER,
   wifi_used_time INTEGER,
   bt_connected_times INTEGER,
   bt_usage_mode INTEGER,
   charge_times INTEGER,
   charge_duration INTEGER,
   wireless_charge_duration INTEGER,
   usb_charge_duration INTEGER,
   ac_charge_duration INTEGER,
   wireless_charge_level INTEGER,
   usb_charge_level INTEGER,
   ac_charge_level INTEGER,
   total_charge_level INTEGER,
   full_charge_times INTEGER,
   outof_power_times INTEGER,
   low_battery_times INTEGER,
   score INTEGER,   
   drain_duration INTEGER,
   total_drain_level INTEGER,
   update_time INTEGER,
   CONSTRAINT pk_agg_battery_drain_info PRIMARY KEY(day)
);

-- creation for a daily aggregation application data infor;   
CREATE TABLE IF NOT EXISTS agg_daily_app_info (
   day INTEGER,
   day_Of_week INTEGER,
   app_id INTEGER,
   fore_drain_power INTEGER,
   back_drain_power INTEGER,
   total_drain_power INTEGER,
   mobile_data_usage INTEGER,
   wifi_data_usage INTEGER,
   used_time INTEGER,
   update_time INTEGER,
   fore_wifi_data INTEGER,
   fore_mobile_data INTEGER,
   CONSTRAINT pk_agg_battery_drain_info PRIMARY KEY(day,app_id)
);
 
-- creation for app table which contains all apps installed and removed in device;   
CREATE TABLE IF NOT EXISTS app (
   app_id INTEGER PRIMARY KEY AUTOINCREMENT, 
   app_name TEXT,
   package_name TEXT,
   app_description TEXT,
   app_type INTEGER,
   risk_level INTEGER,
   is_initial_scan INTEGER,
   risk_ignore INTEGER,
   install_time INTEGER,
   upgrade_time INTEGER,
   remove_time INTEGER,
   version_name TEXT,
   version_code INTEGER,
   is_launchable INTEGER,
   updatetime INTEGER,
   permission TEXT,
   UNIQUE (package_name)
);

-- creation for score table to save score information.   
CREATE TABLE IF NOT EXISTS score (
   day INTEGER,
   category INTEGER,
   behaviour INTEGER,
   frequency INTEGER,
   update_time INTEGER   
);

-- creation for wifi_ssid table which contains wifi ssid available to the device;   
CREATE TABLE IF NOT EXISTS wifi_ssid (
   ssid_id INTEGER PRIMARY KEY AUTOINCREMENT, 
   ssid TEXT,
   bssid TEXT,
   capabilities TEXT,
   signal_strength INTEGER,
   frequency INTEGER,
   UNIQUE (bssid)
);

--creation of user logs table
CREATE TABLE IF NOT EXISTS usage_logs (
  activity_name TEXT,
  activity_action TEXT,
  log_time INTEGER,
  activity_id INTEGER,
  action_id INTEGER,
  action_variable TEXT
);

CREATE TABLE IF NOT EXISTS call_number (
    phone_number_id	INTEGER PRIMARY KEY AUTOINCREMENT,
    phone_number TEXT,
    UNIQUE (phone_number)
);

--creation of app usage table
CREATE TABLE IF NOT EXISTS app_usage (
  app_id INTEGER,
  log_time INTEGER,
  usage_period INTEGER,
  launch_cnt INTEGER,
  location_id INTEGER,
  activity_name TEXT,
  fore_wifi_data INTEGER,
  fore_mobile_data INTEGER
);
CREATE INDEX idx_app_usage_log_time ON app_usage (log_time ASC);

--creation of call_log table
CREATE TABLE IF NOT EXISTS call_log (
call_id	INTEGER PRIMARY KEY AUTOINCREMENT,
call_type INTEGER,
phone_number_id	INTEGER,
start_time INTEGER,
end_time INTEGER,
cell_info_id INTEGER,
rssi_voice INTEGER,
signal_level INTEGER,
is_tagged INTEGER,
call_status INTEGER,
wifi_ssid_id INTEGER
);

--creation of report_card table
CREATE TABLE IF NOT EXISTS report_card (
report_key TEXT,
report_value TEXT
);

CREATE INDEX idx_dcevent2_time ON DCEvent2 (time ASC);
CREATE INDEX idx_appCrash_crashTime ON app_crash (crash_time ASC);
CREATE INDEX idx_alertLog_logTime ON alertLog (log_time ASC);
CREATE INDEX idx_batteryIdleDrainInfo_endTime ON batteryIdleDrainInfo (end_time ASC);
CREATE INDEX idx_aggDailyOverallInfo_day ON agg_daily_overall_info (day ASC);
CREATE INDEX idx_aggDailyAppInfo_day ON agg_daily_app_info (day ASC);
CREATE INDEX idx_score_day ON score (day ASC);
CREATE INDEX idx_call_log_start_time ON call_log (start_time ASC);

-- creation for second aggregation on device health   
CREATE TABLE IF NOT EXISTS agg_device_health (
   category_name TEXT,   
   category_value TEXT
);

-- creation for second aggregation on application details   
CREATE TABLE IF NOT EXISTS agg_app_details (
   pkg_name TEXT,
   app_name TEXT,
   related_value REAL,
   category TEXT
);

-- creation for second aggregation on application details   
CREATE TABLE IF NOT EXISTS agg_power_details (
   time INTEGER,   
   value REAL,
   category TEXT,
   power_off INTEGER,
   charge_status INTEGER
);

-- creation for event based data traffic stat.
CREATE TABLE IF NOT EXISTS event_data_usage (
  _id INTEGER PRIMARY KEY AUTOINCREMENT,
  time INTEGER,
  event_id INTEGER,
  network_type INTEGER,
  app_id INTEGER, 
  traffic_sent INTEGER,
  traffic_received INTEGER,
  total_traffic INTEGER
);
CREATE INDEX idx_event_data_usage_time ON event_data_usage (time ASC);
CREATE INDEX idx_event_data_usage_pkg ON event_data_usage (app_id ASC);

-- creation for daily hights status, if true, show the item, else hide it.
-- result: 0:false, 1:true
CREATE TABLE IF NOT EXISTS daily_highlights (
  category TEXT,
  result INTEGER,
  content TEXT
);

-- Community info tables

CREATE TABLE IF NOT EXISTS community_info (
  community INTEGER,
  community_size INTEGER
);

CREATE TABLE IF NOT EXISTS community_statistics_info (
  community INTEGER,
  statistics_type INTEGER,
  value REAL,
  distribution TEXT
);

CREATE TABLE IF NOT EXISTS community_app_info_user_action (
  app_id INTEGER NOT NULL,
  aspect INTEGER NOT NULL,
  value INTEGER,
  update_time INTEGER,
  
  PRIMARY KEY (app_id, aspect)
);

-- App Rating table
CREATE TABLE IF NOT EXISTS app_user_rating (
  app_id INTEGER NOT NULL,
  rating_type INTEGER NOT NULL,
  rating_value INTEGER NOT NULL,
  update_time INTEGER,

  PRIMARY KEY (app_id, rating_type)
);

CREATE TABLE IF NOT EXISTS sys_event (
  event_id INTEGER PRIMARY KEY,  
  event_type TEXT
);

CREATE TABLE IF NOT EXISTS signal_power_usage (
  _id INTEGER PRIMARY KEY AUTOINCREMENT,
  timestamp INTEGER,
  none_level INTEGER,
  poor_level INTEGER,
  moderate_level INTEGER,
  good_level INTEGER,
  great_level INTEGER,
  scan_level INTEGER
);

--Feed sys_event table(49 records)
insert into sys_event(event_id,event_type) values (1,'EVENT_APP_INSTALLED');
insert into sys_event(event_id,event_type) values (2,'EVENT_APP_REMOVED');
insert into sys_event(event_id,event_type) values (3,'EVENT_APP_STARTED');       		
insert into sys_event(event_id,event_type) values (4,'EVENT_BATTERY_LOW');
insert into sys_event(event_id,event_type) values (5,'EVENT_BATTERY_OKAY');
insert into sys_event(event_id,event_type) values (6,'EVENT_BATTERY_FULL');  		
insert into sys_event(event_id,event_type) values (7,'EVENT_BATTERY_CHANGE');
insert into sys_event(event_id,event_type) values (8,'EVENT_BLUETOOTH_CONNECT');
insert into sys_event(event_id,event_type) values (9,'EVENT_BLUETOOTH_DISCONNECT'); 
insert into sys_event(event_id,event_type) values (10,'EVENT_BT_STATE_ON');
insert into sys_event(event_id,event_type) values (11,'EVENT_BT_STATE_OFF');
insert into sys_event(event_id,event_type) values (12,'EVENT_BT_STATE_TURNING_ON');         
insert into sys_event(event_id,event_type) values (13,'EVENT_BT_STATE_TURNING_OFF');
insert into sys_event(event_id,event_type) values (14,'EVENT_BT_STATE_UNKNOWN');
insert into sys_event(event_id,event_type) values (15,'EVENT_CALLFINISH'); 		
insert into sys_event(event_id,event_type) values (16,'EVENT_DATA_CONNECT');
insert into sys_event(event_id,event_type) values (17,'EVENT_DATA_DISCONNECT');
insert into sys_event(event_id,event_type) values (18,'EVENT_GPS_EVENT_SATELLITE_STATUS'); 
insert into sys_event(event_id,event_type) values (19,'EVENT_GPS_EVENT_STOPPED');
insert into sys_event(event_id,event_type) values (20,'EVENT_GPS_EVENT_STARTED');
insert into sys_event(event_id,event_type) values (21,'EVENT_GPS_EVENT_FIRST_FIXD'); 
insert into sys_event(event_id,event_type) values (22,'EVENT_INCOMINGCALL');
insert into sys_event(event_id,event_type) values (23,'EVENT_MMS_CONNECT');
insert into sys_event(event_id,event_type) values (24,'EVENT_MMS_DISCONNECT');         
insert into sys_event(event_id,event_type) values (25,'EVENT_MMS_INCOMIING');
insert into sys_event(event_id,event_type) values (26,'EVENT_MMS_OUTGOING');
insert into sys_event(event_id,event_type) values (27,'EVENT_OUTGOINGCALL'); 
insert into sys_event(event_id,event_type) values (28,'EVENT_PERIODIC_CHECK');
insert into sys_event(event_id,event_type) values (29,'EVENT_PERIODIC_UPLOAD');
insert into sys_event(event_id,event_type) values (30,'EVENT_POWER_OFF'); 	
insert into sys_event(event_id,event_type) values (31,'EVENT_POWER_ON');
insert into sys_event(event_id,event_type) values (32,'EVENT_SCREEN_OFF');
insert into sys_event(event_id,event_type) values (33,'EVENT_SCREEN_ON');         
insert into sys_event(event_id,event_type) values (34,'EVENT_SIGNAL_CHANGE');
insert into sys_event(event_id,event_type) values (35,'EVENT_SMS_INCOMING');
insert into sys_event(event_id,event_type) values (36,'EVENT_SMS_OUTGOING');
insert into sys_event(event_id,event_type) values (37,'EVENT_POWER_PLUGGED');
insert into sys_event(event_id,event_type) values (38,'EVENT_POWER_UNPLUGGED');
insert into sys_event(event_id,event_type) values (39,'EVENT_USERPRESENT'); 	
insert into sys_event(event_id,event_type) values (40,'EVENT_WIFI_CONNECT');
insert into sys_event(event_id,event_type) values (41,'EVENT_WIFI_DISCONNECT');
insert into sys_event(event_id,event_type) values (42,'EVENT_WIFI_STATE_ON');         		
insert into sys_event(event_id,event_type) values (43,'EVENT_WIFI_STATE_OFF');
insert into sys_event(event_id,event_type) values (44,'EVENT_WIFI_STATE_ENABLING');
insert into sys_event(event_id,event_type) values (45,'EVENT_WIFI_STATE_DISABLING'); 
insert into sys_event(event_id,event_type) values (46,'EVENT_WIFI_STATE_UNKNOWN');
insert into sys_event(event_id,event_type) values (47,'EVENT_OFFHOOK');
insert into sys_event(event_id,event_type) values (48,'EVENT_DAILY_CHECK'); 
insert into sys_event(event_id,event_type) values (49,'EVENT_CELL_LOCATION_CHANGE');
insert into sys_event(event_id,event_type) values (50,'EVENT_USER_LAUNCH_MOBIE');
insert into sys_event(event_id,event_type) values (51,'EVENT_PERIODIC_CHECK_30SECS');
insert into sys_event(event_id,event_type) values (52,'EVENT_LOCATION_CHANGE');



CREATE TABLE IF NOT EXISTS preference_store (
  category TEXT NOT NULL,
  key TEXT NOT NULL,
  value TEXT,
  update_time INTEGER,
  data_type TEXT,
  
  PRIMARY KEY (category, key)
);


--===================== VIEW ===================--

CREATE VIEW IF NOT EXISTS v_call_log AS
    SELECT call_id, call_type, call_number.phone_number, call_number.phone_number_id,
    start_time,end_time,cell_info.cell_id,cell_info.lac,rssi_voice ,signal_level,is_tagged ,call_status, wifi_ssid.ssid
    FROM call_log
    JOIN call_number ON call_log.phone_number_id = call_number.phone_number_id
    JOIN cell_info ON call_log.cell_info_id = cell_info.cell_info_id
    LEFT OUTER JOIN wifi_ssid ON call_log.wifi_ssid_id = wifi_ssid.ssid_id;

CREATE VIEW IF NOT EXISTS v_agg_daily_app_info AS
    SELECT agg.day, agg.day_Of_week, app.app_name, app.package_name as pkg_name, fore_drain_power, back_drain_power,
           total_drain_power, mobile_data_usage, wifi_data_usage, used_time, app.app_type
    FROM agg_daily_app_info agg 
    JOIN app ON agg.app_id = app.app_id;
    
CREATE VIEW IF NOT EXISTS v_dcevent2 AS
    SELECT _id, r.event_type as event, c.cell_id AS cellid, c.lac, mobile_networktype,
    isroaming,rssi_voice, battery_level, battery_voltage, app.app_name AS appattop, charge_status,
    w.ssid AS wifissid, w.bssid AS wifibssid,
    trafficstatsall_tx,trafficstatsall_rx,trafficstatsmobile_tx,trafficstatsmobile_rx,wifi_status,
    isbluetoothon,gps_status,wifi_avail_ssid,time,wifi_ssid_id, app_at_top_id
    FROM DCEvent2 e
    JOIN sys_event r ON e.event_id = r.event_id
    LEFT OUTER JOIN app ON e.app_at_top_id = app.app_id
    LEFT OUTER JOIN wifi_ssid w ON e.wifi_ssid_id = w.ssid_id
    LEFT OUTER JOIN cell_info c ON e.cell_info_id = c.cell_info_id;

CREATE VIEW IF NOT EXISTS v_app_crash AS
    SELECT crash_id, app.app_name, crash.app_version, app.package_name,crash_time,crash_msg,crash_type, crash.app_id
    FROM app_crash crash 
    JOIN app ON crash.app_id = app.app_id;

CREATE VIEW IF NOT EXISTS v_timeBasedPatternData AS
    SELECT day_of_week, hour, charge_start_time, charge_level_increase, charge_duration, day, 
    battery_changed_level, is_charge, wifi_ssid.bssid AS wifibssid, wifi_ssid.ssid AS wifissid, t.wifi_ssid_id
    FROM timeBasedPatternData t
    LEFT OUTER JOIN wifi_ssid ON t.wifi_ssid_id = wifi_ssid.ssid_id;

CREATE VIEW IF NOT EXISTS v_event_data_usage AS
    SELECT _id, time, r.event_type as event, network_type, app.app_id, app.package_name, app.app_name, traffic_sent,  traffic_received,  total_traffic
    FROM event_data_usage
    JOIN app ON event_data_usage.app_id = app.app_id    
    JOIN sys_event r ON event_data_usage.event_id = r.event_id;

--creation of sys_parameter table
CREATE TABLE IF NOT EXISTS sys_parameter (
key TEXT,
value_in_text TEXT,
value_in_int INTEGER,
type TEXT
);

INSERT INTO sys_parameter(key, value_in_int, type) VALUES('DAILY_AGG', 0, 'AGG');
INSERT INTO sys_parameter(key, value_in_int, type) VALUES('DEVICEHEALTH_AGG', 0, 'AGG');
INSERT INTO sys_parameter(key, value_in_int, type) VALUES('LOCATION_AGG', 0, 'AGG');

--Create table for activity_log,
CREATE TABLE IF NOT EXISTS activity_log (
  _id INTEGER primary key autoincrement,
  log_time INTEGER,
  category_name TEXT,
  sub_category_name TEXT,
  params TEXT,
  category_id INTEGER,
  sub_category_id INTEGER
);
CREATE INDEX idx_activity_log_log_time ON activity_log (log_time ASC);

-- Create table for Power Optimization mode and action details
CREATE TABLE IF NOT EXISTS power_optim_mode_action_details (
  mode_id INTEGER,
  location_id INTEGER,
  action_id INTEGER,
  control_value INTEGER,
  control_set_value INTEGER,
  updated_time INTEGER
);

CREATE TABLE IF NOT EXISTS event_app_power_info (
  _id INTEGER primary key autoincrement,
  time INTEGER,
  event_id INTEGER,
  uid INTEGER,
  app_id INTEGER,
  cpu_time INTEGER,
  cpu_fore_time INTEGER,
  wakelock_time INTEGER,
  tcp_send_bytes INTEGER,
  tcp_receive_bytes INTEGER,
  wifi_running_time INTEGER,
  wifi_scanning_time INTEGER,
  wifi_full_time INTEGER,
  gps_time INTEGER,
  total_time INTEGER,
  total_power INTEGER
);

CREATE TABLE IF NOT EXISTS screen_power_usage (
  _id INTEGER PRIMARY KEY AUTOINCREMENT,
  timestamp INTEGER,
  dark_level INTEGER,
  dim_level INTEGER,
  medium_level INTEGER,
  light_level INTEGER,
  bright_level INTEGER
);

--Create view for event_app_power_info,
CREATE VIEW IF NOT EXISTS v_event_app_power_info AS
    SELECT _id, time, r.event_type as event, app.package_name, app.app_name, total_time, total_power, app.app_id,
    cpu_time, cpu_fore_time
    FROM event_app_power_info
    JOIN app ON event_app_power_info.app_id = app.app_id
   	JOIN sys_event r ON event_app_power_info.event_id = r.event_id;

-- Night mode
-- Wifi(0), Data(1), BT(2), Sound(3), Vibrate(4), Airplane(5), Brightness(6), SleepingTime(7);
-- NotChange(-1), Off(0), On(1), Set(2); automatic for brightness it is 0, and mute for sound it is 0 too
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (0, 0, 0, -1, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (0, 0, 1, -1, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (0, 0, 2, -1, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (0, 0, 3, -1, -1);
--INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (0, 0, 5, 1, -1);
--INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (0, 0, 6, 1, -1);

-- Home mode
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (1, 0, 0, 1, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (1, 0, 1, -1, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (1, 0, 2, 0, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (1, 0, 3, -1, -1);
--INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (1, 0, 6, 0, -1);

-- Office mode
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (2, 0, 0, 1, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (2, 0, 1, -1, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (2, 0, 2, 0, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (2, 0, 3, -1, -1);
--INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (2, 0, 6, 0, -1);

-- Elsewhere known location mode
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (3, 0, 0, -1, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (3, 0, 1, -1, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (3, 0, 2, -1, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (3, 0, 3, -1, -1);
--INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (3, 0, 6, -1, -1);

-- Elsewhere unknown mode
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (4, 0, 0, 0, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (4, 0, 1, -1, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (4, 0, 2, 1, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (4, 0, 3, -1, -1);
--INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (4, 0, 6, 0, -1);

-- Elsewhere known template mode
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (5, 0, 0, 1, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (5, 0, 1, -1, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (5, 0, 2, 0, -1);
INSERT INTO power_optim_mode_action_details(mode_id, location_id, action_id, control_value, control_set_value) values (5, 0, 3, -1, -1);

-- Create table for mode related feature
CREATE TABLE IF NOT EXISTS modes (
  mode_id INTEGER,
  mode_name TEXT,
  is_active INTEGER,
  action_id INTEGER,
  control_value INTEGER,
  control_set_value INTEGER,
  is_default INTEGER,
  updated_time INTEGER
);
INSERT INTO modes(mode_id,mode_name,is_active, action_id,control_value,control_set_value,is_default,updated_time) values (1, 'Super Saver', 0, 0, 0, -1, 1, null);
INSERT INTO modes(mode_id,mode_name,is_active, action_id,control_value,control_set_value,is_default,updated_time) values (1, 'Super Saver', 0, 1, 0, -1, 1, null);
INSERT INTO modes(mode_id,mode_name,is_active, action_id,control_value,control_set_value,is_default,updated_time) values (1, 'Super Saver', 0, 2, 0, -1, 1, null);
INSERT INTO modes(mode_id,mode_name,is_active, action_id,control_value,control_set_value,is_default,updated_time) values (1, 'Super Saver', 0, 3, 0, -1, 1, null);

INSERT INTO modes(mode_id,mode_name,is_active, action_id,control_value,control_set_value,is_default,updated_time) values (2, 'Silent', 0, 0, -1, -1, 1, null);
INSERT INTO modes(mode_id,mode_name,is_active, action_id,control_value,control_set_value,is_default,updated_time) values (2, 'Silent', 0, 1, -1, -1, 1, null);
INSERT INTO modes(mode_id,mode_name,is_active, action_id,control_value,control_set_value,is_default,updated_time) values (2, 'Silent', 0, 2, -1, -1, 1, null);
INSERT INTO modes(mode_id,mode_name,is_active, action_id,control_value,control_set_value,is_default,updated_time) values (2, 'Silent', 0, 3,  0, -1, 1, null);

-- creation for app group table    
CREATE TABLE IF NOT EXISTS app_group (
  group_id INTEGER NOT NULL,
  group_name TEXT NOT NULL,
  package_name TEXT ,
  update_time INTEGER,
  bg_uri TEXT,
  icon_uri TEXT,
  version INTEGER,
  PRIMARY KEY (group_id, group_name)
);

-- creation for recommended app group table    
CREATE TABLE IF NOT EXISTS recommend_app (
  group_name TEXT NOT NULL,
  package_name TEXT ,
  state INTEGER,
  PRIMARY KEY (group_name, package_name)
);

-- creation for avatar table    
CREATE TABLE IF NOT EXISTS avatar (
  package_name TEXT,
  avatar_type INTEGER,
  create_time INTEGER,
  update_time INTEGER,
  info	TEXT,
  used_flag INTEGER,
  
  PRIMARY KEY (package_name, avatar_type)
);

-- creation for avatar notification display user choice table.    
CREATE TABLE IF NOT EXISTS avatar_notif_user_choice (
  package_name TEXT,
  avatar_type INTEGER,
  avatar_sub_type INTEGER,
  dont_show INTEGER,
  update_time INTEGER,
  
  PRIMARY KEY (package_name, avatar_type, avatar_sub_type)
);

-- for notification display
CREATE TABLE IF NOT EXISTS notification_display (
  content_skey INTEGER,
  has_displayed INTEGER
);


-- tables for location from R3 release

CREATE TABLE IF NOT EXISTS location_profile (
  location_id INTEGER PRIMARY KEY,
  location_name TEXT,
  auto_optimized INTEGER,
  bed_time_enabled INTEGER,
  bg_uri TEXT,
  update_time INTEGER
);

-- location_type:
-- SSID(0)
-- Address(1)
CREATE TABLE IF NOT EXISTS location_entry (
  location_id_skey INTEGER,
  location_type INTEGER,
  location_info TEXT,
  update_time INTEGER,
  location_latLng TEXT,
  location_sub_id INTEGER PRIMARY KEY AUTOINCREMENT
);

-- control_value:
-- NOT_MANAGED = 0;
-- ON = 1;
-- OFF = 2;

-- control_type:
-- WIFI = 0;
-- DATA = 1;
-- BLUETOOTH = 2;
-- SOUND = 3;
-- VIBRATE = 4;
-- BRIGHTNESS = 5;

-- control_category:
-- CATEGORY_AUTO_OPTIMIZE(0)
-- CATEGORY_BED_TIME(1)
CREATE TABLE IF NOT EXISTS location_control_config (
  location_id_skey INTEGER,
  control_category INTEGER,
  control_type INTEGER,
  control_value INTEGER,
  update_time INTEGER,

  PRIMARY KEY (location_id_skey, control_category, control_type)
);

-- insert 4 locations by default
INSERT INTO location_profile(location_id,location_name,auto_optimized,bed_time_enabled,bg_uri,update_time) values (0, 'Home', 1, 1, null, strftime('%s','now')*1000);
INSERT INTO location_profile(location_id,location_name,auto_optimized,bed_time_enabled,bg_uri,update_time) values (1, 'Work', 1, 0, null, strftime('%s','now')*1000);
INSERT INTO location_profile(location_id,location_name,auto_optimized,bed_time_enabled,bg_uri,update_time) values (2, 'Car', 1, 0, null, strftime('%s','now')*1000);
INSERT INTO location_profile(location_id,location_name,auto_optimized,bed_time_enabled,bg_uri,update_time) values (3, 'Out', 1, 0, null, strftime('%s','now')*1000);

CREATE VIEW IF NOT EXISTS v_locationBasedPatternData AS
     SELECT l.cell_info_id, c.lac, c.cell_id AS cellid, wifi_ssid.bssid AS wifibssid, wifi_ssid.ssid AS wifissid, wifi_ssid_id,
     location_mode, confirmed, network_latitude, network_longitude, availbssids, l.update_time, location_entry.location_id_skey as location_id,  location_name
     FROM locationBasedPatternData l
     JOIN cell_info c ON l.cell_info_id = c.cell_info_id
     LEFT OUTER JOIN wifi_ssid ON l.wifi_ssid_id = wifi_ssid.ssid_id
     LEFT OUTER JOIN location_entry ON wifi_ssid.ssid=location_entry.location_info AND location_entry.location_type=0;

--INSERT INTO app_group (group_id, group_name, package_name, bg_uri, icon_uri, update_time) values (1, 'My Interest', '', 'file:///android_asset/bg/bg_collection_personalinterest.jpg', 'ic_coll_personalization', strftime('%s','now')*1000 + 1000);
--INSERT INTO app_group (group_id, group_name, package_name, bg_uri, icon_uri, update_time) values (1, 'Commute', '', 'file:///android_asset/bg/bg_collection_commute.jpg', 'ic_coll_transportation', strftime('%s','now')*1000 + 1000);

CREATE TABLE db_operation_log ( action TEXT NOT NULL, table_name TEXT NOT NULL, criteria TEXT, update_time INTEGER);

CREATE TRIGGER after_avatar_delete after delete ON avatar
    BEGIN
      INSERT INTO db_operation_log(action, table_name, criteria, update_time)
      VALUES ('DELETE','avatar','package_name='''||old.package_name||''''||' and avatar_type='||old.avatar_type,strftime('%s','now')*1000 + 1000); END;

CREATE TRIGGER after_appgroup_delete after delete ON app_group
    BEGIN
      INSERT INTO db_operation_log(action, table_name, criteria, update_time)
      VALUES ('DELETE','app_group','group_name='''||old.group_name||'''',strftime('%s','now')*1000 + 1000); END;

CREATE TRIGGER after_appgroup_update after update ON app_group
    BEGIN
      INSERT INTO db_operation_log(action, table_name, criteria, update_time)
      VALUES ('UPDATE','app_group','group_name='''||old.group_name||'''',strftime('%s','now')*1000 + 1000); END;

CREATE TRIGGER after_preferencestore_delete after delete ON preference_store
    BEGIN
      INSERT INTO db_operation_log(action, table_name, criteria, update_time)
      VALUES ('DELETE','preference_store','category='''||old.category||''''||' and key='''||old.key||'''',strftime('%s','now')*1000 + 1000); END;

CREATE TRIGGER after_locationprofile_delete after delete ON location_profile
    BEGIN
      INSERT INTO db_operation_log(action, table_name, criteria, update_time)
      VALUES ('DELETE','location_profile','location_id='||old.location_id,strftime('%s','now')*1000 + 1000); END;

CREATE TRIGGER after_locationentry_delete after delete ON location_entry
    BEGIN
      INSERT INTO db_operation_log(action, table_name, criteria, update_time)
      VALUES ('DELETE','location_entry','location_id='||old.location_id_skey,strftime('%s','now')*1000 + 1000); END;

CREATE TRIGGER after_locationcontrolconfig_delete after delete ON location_control_config
    BEGIN
      INSERT INTO db_operation_log(action, table_name, criteria, update_time)
      VALUES ('DELETE','location_control_config','location_id='||old.location_id_skey,strftime('%s','now')*1000 + 1000); END;

--Create table for app_foreground_time,
CREATE TABLE IF NOT EXISTS app_foreground_time (
  app_id INTEGER,
  foreground_time INTEGER,

  PRIMARY KEY (app_id)
);

-- aggregation table for location change.    
CREATE TABLE IF NOT EXISTS agg_daily_location_info (
   day INTEGER,
   day_Of_week INTEGER,
   location_id INTEGER,
   location_duration INTEGER,
   mobile_data_usage INTEGER,
   wifi_data_usage INTEGER,
   mobile_used_time INTEGER,
   wifi_used_time INTEGER,
   charge_duration INTEGER,
   total_charge_level INTEGER,
   drain_duration INTEGER,
   total_drain_level  INTEGER,
   update_time INTEGER,
   PRIMARY KEY(day, location_id)
);

-- Create table for Communication Framework
CREATE TABLE IF NOT EXISTS remote_message (
  message_id INTEGER NOT NULL,
  key TEXT NOT NULL,
  value TEXT,
  data_type TEXT,
  update_time INTEGER,
  PRIMARY KEY (message_id)
);

CREATE TABLE IF NOT EXISTS favorites (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    item_type INTEGER,
    screen INTEGER,
    cell_x INTEGER,
    cell_y INTEGER,
    span_x INTEGER,
    span_y INTEGER,
    package_name TEXT,
    appWidget_id INTEGER NOT NULL DEFAULT -1,
    appWidget_provider TEXT,
    appWidget_type INTEGER,
    update_time INTEGER NOT NULL DEFAULT 0
);

CREATE TRIGGER after_favorites_delete AFTER delete ON favorites
    BEGIN
      INSERT INTO db_operation_log(action, table_name, criteria, update_time)
      VALUES ('DELETE','favorites','_id='''||old._id||'''',strftime('%s','now')*1000 + 1000); END;

CREATE TRIGGER after_favorites_update AFTER UPDATE ON favorites
  BEGIN
    INSERT INTO db_operation_log(action, table_name, criteria, update_time)
          VALUES ('UPDATE','favorites','_id='''||old._id||'''',strftime('%s','now')*1000 + 1000); END;

CREATE TABLE IF NOT EXISTS widget_previews (
    name TEXT NOT NULL,
    preview_size TEXT NOT NULL,
    preview_bitmap BLOB,
    PRIMARY KEY (name, preview_size)
);

-- creation for recommended app_info group table
CREATE TABLE IF NOT EXISTS recommend_app_info (
  group_name TEXT NOT NULL,
  package_name TEXT ,
  app_name TEXT,
  app_icon_uri TEXT,
  update_time INTEGER,
  PRIMARY KEY (group_name, package_name)
);

-- Zone initialization
INSERT INTO preference_store (category, key, value, update_time, data_type)
SELECT 'Install', 'isLocationBasedZoneEnabled', 'false', strftime('%s','now')*1000, 'Boolean';

INSERT INTO preference_store (category, key, value, update_time, data_type)
SELECT 'Install', 'defaultZone', 'My Favorites', strftime('%s','now')*1000, 'String';

INSERT INTO preference_store (category, key, value, update_time, data_type)
SELECT 'Install', 'defaultHomePage', '1', strftime('%s','now')*1000, 'Long';

CREATE TABLE IF NOT EXISTS location_address (
  address_id  INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  address     TEXT NOT NULL,
  latitude    DOUBLE NOT NULL,
  longitude   DOUBLE NOT NULL,
  update_time INTEGER,
  UNIQUE(latitude,longitude)
);

CREATE TABLE IF NOT EXISTS location_address_log (
  address_id   INTEGER NOT NULL,
  wifi_ssid    TEXT,
  event_id     INTEGER,
  log_time     INTEGER NOT NULL PRIMARY KEY
);

CREATE INDEX IF NOT EXISTS location_address_log_on_address ON location_address_log (address_id,log_time);

CREATE TABLE IF NOT EXISTS location_address_learning (
  location_id     INTEGER NOT NULL,
  address_id      INTEGER NOT NULL,
  wifi_ssid       TEXT,
  learning_type   INTEGER NOT NULL,
  learning_state  INTEGER NOT NULL,
  update_time     INTEGER,
  UNIQUE(address_id,learning_type)
);
